# Release history

#### 3.4.0
Add md files.

#### 3.3.0
Dependency update 1.60.0 - 2.0.0.

#### 3.2.0
Force update AWS CDK dependency version to 1.44.0.

#### 3.1.0
Added the ability to add custom commands to buildspec.

#### 3.0.1
Bug fix.

#### 3.0.0
Moved SSH parameters to a separate class.

#### 2.3.0
Add ability to specify KMS key for secret decryption.

#### 2.2.0
Add ability to specify arguments for install and test scripts.

#### 2.1.0
Add error and throttles alarms. Add ability to specify lambda environment.
Add reserved concurrent executions.

#### 2.0.1
Bug fix.

#### 2.0.0
Refactor. Increase clarity.

#### 1.1.0
Major refactoring and minor updates and fixes.

#### 1.0.1
Made use CDK version 1.27.0

#### 1.0.0
Initial commit.
